# $Id: 03_dbquery.t,v 1.2 2005/11/25 22:01:28 pythontech Exp $
use strict;
use Test::More tests => 21;

use lib 't/lib';
use DbUtil;

use PythonTech::Triples::DBHash;
use DB_File;

my $dbname = 't/new03.3db';

# Create test data
dbwrite($dbname, '
v1 = a
v2 = b
v3 = c
v4 = d
v5 = e
ia = 1
ib = 2
ic = 3
id = 4
ie = 5
l = 5
t1,2,3 = 1
t1,2,4 = 1
t1,5,3 = 1
o1,2 = 3+4
o1,5 = 3
s2,3 = 1
s2,4 = 1
s5,3 = 1
');

my $tr = new PythonTech::Triples::DBHash(filename => $dbname,
					 access => 'r');
is($tr->test('a','b','c'), 1, 'simple test');
is($tr->test('a','b','d'), 1, 'simple test');
is($tr->test('a','b','a'), undef, 'test no, resource exists');
is($tr->test('x','b','c'), undef, 'test no, subject unknown');
is($tr->test('a','y','c'), undef, 'test no, predicate unknown');
is($tr->test('a','b','z'), undef, 'test no, object unknown');
is(&qt($tr->query('a','b',undef)), 'c;d', 'query sp?');
is(&qt($tr->query('a',undef,'c')), 'b;e', 'query s?p');
is(&qt($tr->query('a',undef,undef)), 'b,c;b,d;e,c', 'query s??');
is(&qt($tr->query(undef,'b','c')), 'a', 'query ?po');
is(&qt($tr->query(undef,'b',undef)), 'a,c;a,d', 'query ?p?');
is(&qt($tr->query(undef,undef,'d')), 'a,b', 'query ??o');
is(&qt($tr->query(undef,undef,undef)), 'a,b,c;a,b,d;a,e,c', 'query ???');
is(&j($tr->sp2o('a','b')), 'c,d', 'sp2o');
is(&j($tr->sp2o('a','y')), '', 'sp2o no match');
like(scalar($tr->sp2o('a','b')), qr/^(c|d)$/, 'sp2o scalar');
is(&j($tr->po2s('b','d')), 'a', 'po2s');
is(&j(scalar $tr->po2s('b','d')), 'a', 'po2s scalar');
is(&j($tr->po2s('b','z')), '', 'po2s no match');
is(&j($tr->s2p('a')), 'b,e', 's2p');
is(&j($tr->s2p('c')), '', 's2p no match');

$tr = undef;
unlink($dbname);

sub qt {
    join(";", sort map {join(",",@$_)} @_);
}

sub j {join(",",sort @_)}
